@@ -15,12 +15,12 @@ from typing import (
     cast,
 )
 
-from OpenSSL import crypto
+from cryptography import x509
+from cryptography.hazmat.primitives.serialization import Encoding
 
 import josepy
 from josepy import b64, errors, json_util, jwa
 from josepy import jwk as jwk_mod
-from josepy import util
 
 
 class MediaType:
@@ -80,7 +80,7 @@ class Header(json_util.JSONObjectWithFields):
     )
     kid: Optional[str] = json_util.field("kid", omitempty=True)
     x5u: Optional[bytes] = json_util.field("x5u", omitempty=True)
-    x5c: Tuple[util.ComparableX509, ...] = json_util.field("x5c", omitempty=True, default=())
+    x5c: Tuple[x509.Certificate, ...] = json_util.field("x5c", omitempty=True, default=())
     x5t: Optional[bytes] = json_util.field("x5t", decoder=json_util.decode_b64jose, omitempty=True)
     x5tS256: Optional[bytes] = json_util.field(
         "x5t#S256", decoder=json_util.decode_b64jose, omitempty=True
@@ -138,21 +138,25 @@ class Header(json_util.JSONObjectWithFields):
 
     @x5c.encoder  # type: ignore
     def x5c(value):
-        return [
-            base64.b64encode(crypto.dump_certificate(crypto.FILETYPE_ASN1, cert.wrapped))
-            for cert in value
-        ]
+        """
+        .. versionchanged:: 2.0.0
+           The values are now `cryptography.x509.Certificate` objects.
+           Previously these were `josepy.util.ComparableX509` objects, which wrapped
+           `OpenSSL.crypto.X509` objects.
+        """
+        return [base64.b64encode(cert.public_bytes(Encoding.DER)) for cert in value]
 
     @x5c.decoder  # type: ignore
     def x5c(value):
+        """
+        .. versionchanged:: 2.0.0
+           The values are now `cryptography.x509.Certificate` objects.
+           Previously these were `josepy.util.ComparableX509` objects, which wrapped
+           `OpenSSL.crypto.X509` objects.
+        """
         try:
-            return tuple(
-                util.ComparableX509(
-                    crypto.load_certificate(crypto.FILETYPE_ASN1, base64.b64decode(cert))
-                )
-                for cert in value
-            )
-        except crypto.Error as error:
+            return tuple(x509.load_der_x509_certificate(base64.b64decode(cert)) for cert in value)
+        except ValueError as error:
             raise errors.DeserializationError(error)
 
 
@@ -392,8 +396,8 @@ class CLI:
     @classmethod
     def sign(cls, args: argparse.Namespace) -> None:
         """Sign."""
-        key = args.alg.kty.load(args.key.read())
-        args.key.close()
+        with open(args.key, "rb") as fp:
+            key = args.alg.kty.load(fp.read())
         if args.protect is None:
             args.protect = []
         if args.compact:
@@ -422,8 +426,8 @@ class CLI:
 
         if args.key is not None:
             assert args.kty is not None
-            key = args.kty.load(args.key.read()).public_key()
-            args.key.close()
+            with open(args.key, "rb") as fp:
+                key = args.kty.load(fp.read()).public_key()
         else:
             key = None
 
@@ -455,13 +459,13 @@ class CLI:
         subparsers = parser.add_subparsers()
         parser_sign = subparsers.add_parser("sign")
         parser_sign.set_defaults(func=cls.sign)
-        parser_sign.add_argument("-k", "--key", type=argparse.FileType("rb"), required=True)
+        parser_sign.add_argument("-k", "--key", required=True)
         parser_sign.add_argument("-a", "--alg", type=cls._alg_type, default=jwa.RS256)
         parser_sign.add_argument("-p", "--protect", action="append", type=cls._header_type)
 
         parser_verify = subparsers.add_parser("verify")
         parser_verify.set_defaults(func=cls.verify)
-        parser_verify.add_argument("-k", "--key", type=argparse.FileType("rb"), required=False)
+        parser_verify.add_argument("-k", "--key", required=False)
         parser_verify.add_argument("--kty", type=cls._kty_type, required=False)
 
         parsed = parser.parse_args(args)
